dSFMT-jump: dsfmt Namespace Reference

dSFMT-jump 0.1

- Main Page
- Namespaces
- Data Structures
- Files

- Namespace List
- Namespace Members

Functions
dsfmt Namespace Reference

## Functions
static void | polytostring (std::string &x, NTL::GF2X &polynomial)
| converts polynomial to string for convenient use in C language.
static void | stringtopoly (NTL::GF2X &poly, std::string &str)
| converts string to polynomial
static void | calc_jump (std::string &jump_str, NTL::ZZ &step, NTL::GF2X &characteristic)
| calculate the jump polynomial.

## Function Documentation

static void dsfmt::calc_jump | ( | std::string & | jump_str,
|  | NTL::ZZ & | step,
|  | NTL::GF2X & | characteristic
| ) |  | `[inline, static]`

calculate the jump polynomial.

SFMT generates 4 32-bit integers from one internal state.

Parameters:

  jump_str | output string which represents jump polynomial.
  step | jump step of internal state
  characteristic | polynomial

References polytostring().

static void dsfmt::polytostring | ( | std::string & | x,
|  | NTL::GF2X & | polynomial
| ) |  | `[inline, static]`

converts polynomial to string for convenient use in C language.

Parameters:

  x | output string
  polynomial | input polynomial

Referenced by calc_jump().

static void dsfmt::stringtopoly | ( | NTL::GF2X & | poly,
|  | std::string & | str
| ) |  | `[inline, static]`

converts string to polynomial

Parameters:

  str | string
  poly | output polynomial